@@ -76,7 +76,7 @@ public:
 int main(int argc, char* argv[]) {
     if (argc != 2) {
         std::cerr << "Usage: " << argv[0] << " INFILE\n";
-        std::exit(1);
+        return 1;
     }
 
     try {
@@ -100,7 +100,9 @@ int main(int argc, char* argv[]) {
         reader.close();
     } catch (const std::exception& e) {
         std::cerr << e.what() << '\n';
-        std::exit(1);
+        return 1;
     }
+
+    return 0;
 }
 
