@@ -28,7 +28,7 @@ struct ZeroPositionNodeCountHandler : public osmium::handler::Handler {
     // location.
     int count = 0;
     int total_count = 0; // total number of nodes seen
-    const osmium::Location zero = osmium::Location{int32_t(0), int32_t(0)};
+    const osmium::Location zero = osmium::Location{static_cast<int32_t>(0), static_cast<int32_t>(0)};
 
     void node(const osmium::Node& node) {
         // no nodes in the history file have a zero location, and
