@@ -17,8 +17,8 @@ TEST_CASE("Build changeset") {
 
     osmium::builder::add_changeset(buffer,
         _cid(42),
-        _created_at(time_t(100)),
-        _closed_at(time_t(200)),
+        _created_at(static_cast<std::time_t>(100)),
+        _closed_at(static_cast<std::time_t>(200)),
         _num_changes(7),
         _num_comments(3),
         _uid(9),
@@ -44,15 +44,15 @@ TEST_CASE("Build changeset") {
 
     const auto pos = osmium::builder::add_changeset(buffer,
         _cid(43),
-        _created_at(time_t(120)),
+        _created_at(static_cast<std::time_t>(120)),
         _num_changes(21),
         _num_comments(0),
         _uid(9),
         _user("user"),
         _tag("comment", "foo"),
         _tag("foo", "bar"),
-        _comment({time_t(300), 10, "user2", "foo"}),
-        _comments({{time_t(400), 9, "user", "bar"}})
+        _comment({static_cast<std::time_t>(300), 10, "user2", "foo"}),
+        _comments({{static_cast<std::time_t>(400), 9, "user", "bar"}})
     );
 
     const osmium::Changeset& cs2 = buffer.get<osmium::Changeset>(pos);
@@ -151,8 +151,8 @@ TEST_CASE("Change changeset") {
 
     osmium::builder::add_changeset(buffer,
         _cid(42),
-        _created_at(time_t(100)),
-        _closed_at(time_t(200)),
+        _created_at(static_cast<std::time_t>(100)),
+        _closed_at(static_cast<std::time_t>(200)),
         _num_changes(7),
         _num_comments(3),
         _uid(9),
@@ -163,8 +163,8 @@ TEST_CASE("Change changeset") {
     auto& cs = buffer.get<osmium::Changeset>(0);
 
     cs.set_id(12);
-    cs.set_created_at(time_t(200));
-    cs.set_closed_at(time_t(300));
+    cs.set_created_at(static_cast<std::time_t>(200));
+    cs.set_closed_at(static_cast<std::time_t>(300));
     cs.set_num_changes(3);
     cs.set_num_comments(4);
     cs.set_uid(10);
