@@ -6,11 +6,11 @@
 
 TEST_CASE("Check memory usage") {
 #ifdef __linux__
-    osmium::MemoryUsage m1;
+    const osmium::MemoryUsage m1;
     REQUIRE(m1.current() > 1);
     REQUIRE(m1.peak() > 1);
 #else
-    osmium::MemoryUsage m;
+    const osmium::MemoryUsage m;
     REQUIRE(m.current() == 0);
     REQUIRE(m.peak() == 0);
 #endif
